// Demo using DHCP and DNS to perform a web client request.
// 2011-06-08 <jc@wippler.nl> http://opensource.org/licenses/mit-license.php

#include <EtherCard.h>
#include <SPI.h>
#include <EEPROM.h>

// ethernet interface mac address, must be unique on the LAN
static byte mymac[] = { 0x00,0x4f,0x49,0x00,0x00,0x04 };

byte Ethernet::buffer[700];
static uint32_t timer;

const char website[] = "www.google.com";

// called when the client request is complete
static void my_callback (uint8_t status, uint16_t off, uint16_t len) {
  Serial.println(">>>");
  Ethernet::buffer[off+300] = 0;
  Serial.print((const char*) Ethernet::buffer + off);
  Serial.println("...");
}

void setup () {
  Serial.begin(115200);

  Serial.println("\n[webClient]");

  //eg. ether.begin(sizeof Ethernet::buffer, mymac, PD_1, 3) //PD_1 - ENC CS Pin, SPImodule 3
  if (ether.begin(sizeof Ethernet::buffer, mymac) == 0) //DEFAULT: PB_5 - ENC CS Pin, SPImodule 2
    Serial.println( "Failed to access Ethernet controller");
  if (!ether.dhcpSetup())
    Serial.println("DHCP failed");

  ether.printIp("IP:  ", ether.myip);
  ether.printIp("GW:  ", ether.gwip);  
  ether.printIp("DNS: ", ether.dnsip);  

  if (!ether.dnsLookup(website))
    Serial.println("DNS failed");
    
  ether.printIp("SRV: ", ether.hisip);
}

void loop () {
  ether.packetLoop(ether.packetReceive());
  
  if (millis() > timer) {
    timer = millis() + 5000;
    Serial.println();
    Serial.print("<<< REQ ");
    ether.browseUrl("/foo/", "bar", website, my_callback);
  }
}
